import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns

# Définition de la palette de couleurs
color_palette = {
    'gpt-4.5-preview-2025-02-27': '#7abaff',  # bleuEvasion
    'llama3': '#32a68c',  # vertAvenir
    'mistral-small': '#ff6941',  # orangeChaleureux
    'deepseek-r1': '#5862ed'  # indigoInclusif
}

# Charger les données
data = pd.read_csv("../../data/dictator/dictator.csv")  # Remplacez par le bon chemin vers votre fichier CSV

# Création du boxplot
plt.figure(figsize=(8, 6))
sns.boxplot(
    data=data,
    x="model",
    y="my_share",
    hue="model",  # Explicitly assign hue
    palette=color_palette,
    showfliers=False,
    legend=False  # Disable legend since hue is just for color mapping
)

# Ajouter médiane, premier et troisième quartile
for i, model in enumerate(data["model"].unique()):
    subset = data[data["model"] == model]["my_share"]
    median = subset.median()
    q1 = subset.quantile(0.25)
    q3 = subset.quantile(0.75)
    plt.text(i, median, f"{median:.0f}", ha='center', va='bottom', fontsize=10, fontweight='bold', color='black')
    plt.text(i, q1, f"{q1:.0f}", ha='center', va='top', fontsize=9, color='black')
    plt.text(i, q3, f"{q3:.0f}", ha='center', va='bottom', fontsize=9, color='black')

# Labels et titre
plt.xlabel("Model")
plt.ylabel("Share of money allocated to oneself")
plt.title("Distribution of self-allocated share per model in the dictator game")

# Sauvegarde et affichage
plt.savefig("../../figures/dictator/dictator_boxplot.svg", format="svg")