import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns

# Definition of the color palette
color_palette = {
    'gpt-4.5-preview-2025-02-27': '#7abaff',  # BlueEscape
    'llama3': '#32a68c',  # GreenFuture
    'mistral-small': '#ff6941',  # WarmOrange
    'deepseek-r1': '#5862ed'  # InclusiveIndigo
}

# Load the data
data = pd.read_csv("../../data/dictator/dictator.csv")  # Replace with the correct path to your CSV file

# Create the violin plot
plt.figure(figsize=(8, 6))
sns.violinplot(
    data=data,
    x="model",
    y="my_share",
    hue="model",  # Use hue to manage the colors
    palette=color_palette,
    inner="quartile",  # Displays quartiles inside the violin
    density_norm="width"  # Normalizes the width of the violins for comparison
)

# Add vertical lines for strategies
strategy_values = {
    'gpt-4.5-preview-2025-02-27': 70,
    'llama3': 50,
    'mistral-small': 50,
    'deepseek-r1': 50
}

for model, value in strategy_values.items():
    plt.axhline(y=value, color=color_palette[model], linestyle="dashed", linewidth=2, label=f"{model} strategy")

# Set the y-axis limits between 0 and 100
plt.ylim(0, 100)
# Labels and title
plt.xlabel("Model")
plt.ylabel("Share of money assigned to oneself")
plt.title("Distribution of personal share by model in the dictator game")
plt.legend()

# Save and display
plt.savefig("../../figures/dictator/dictator_violin.svg", format="svg")