import asyncio
import statistics
import pandas as pd
from dictator import Dictator

class DictatorExperiment:
    debug = True

    def __init__(self, models: list[str], temperature: float, amount: int, iterations: int, output_file: str):
        self.models = models
        self.temperature = temperature
        self.amount = amount
        self.iterations = iterations
        self.output_file = output_file  # Path to the CSV output file

        # Initialize the CSV file with headers
        with open(self.output_file, 'w', encoding='utf-8') as f:
            f.write("iteration,model,temperature,amount,my_share,other_share,motivation\n")

    async def run_experiment(self):
        # Run the dictator game for each model
        for model in self.models:
            if self.debug:
                print(f"Running experiment for model: {model}")

            # Run the dictator game for the specified number of iterations
            for iteration in range(1, self.iterations + 1):
                game_agent = Dictator(amount=self.amount, model=model, temperature=self.temperature)
                response = await game_agent.run()
                if self.debug:
                    print(response)

                my_share = response['my_share']
                other_share = response['other_share']
                motivation = response.get('motivation', "").replace('"', '""')  # Échapper les guillemets internes

                # Log individual iteration result
                with open(self.output_file, 'a', encoding='utf-8') as f:
                    f.write(f'{iteration},{model},{self.temperature},{self.amount},{my_share},{other_share},"{motivation}"\n')


# Running the experiment
if __name__ == "__main__":
    models = ["llama3", "mistral-small", "deepseek-r1"] # "gpt-4.5-preview-2025-02-27"
    temperature = 0.7
    amount = 100
    iterations = 30
    output_file = '../../data/dictator/dictator.csv'  # Define your CSV output file path

    # Create an experiment object
    experiment = DictatorExperiment(models=models, temperature=temperature, amount=amount, iterations=iterations, output_file=output_file)

    # Run the experiment asynchronously
    asyncio.run(experiment.run_experiment())
    print(f"Experiment results saved to {output_file}")